HtmlSanitizeEx.Scrubber.BasicHTML (html_sanitize_ex v1.5.0)

Allows basic HTML tags to support user input for writing relatively plain text but allowing headings, links, bold, and so on.

Does not allow any styling, HTML5 tags, video embeds etc.

Summary

Functions

before_scrub(arg)

Callback implementation for HtmlSanitizeEx.Scrubber.before_scrub/1.

sanitize(html)

scrub(arg)

Callback implementation for HtmlSanitizeEx.Scrubber.scrub/1.

scrub_attribute(arg1, arg2)

Callback implementation for HtmlSanitizeEx.Scrubber.scrub_attribute/2.

scrub_attributes(tag, attributes)

Callback implementation for HtmlSanitizeEx.Scrubber.scrub_attributes/2.