HtmlSanitizeEx.Scrubber.MarkdownHTML (html_sanitize_ex v1.5.0)

Allows basic HTML tags to support user input for writing relatively plain text with Markdown (GitHub flavoured Markdown supported).

Technically this is a more relaxed version of the BasicHTML scrubber.

Does not allow any styling, HTML5 tags, video embeds etc.

Summary

Functions

before_scrub(html)

Callback implementation for HtmlSanitizeEx.Scrubber.before_scrub/1.

sanitize(html)

scrub(text)

Callback implementation for HtmlSanitizeEx.Scrubber.scrub/1.

scrub_attribute(tag, attribute)

Callback implementation for HtmlSanitizeEx.Scrubber.scrub_attribute/2.

scrub_attributes(tag, attributes)

Callback implementation for HtmlSanitizeEx.Scrubber.scrub_attributes/2.